==> linktools-0.7.11.tar.gz: linktools-0.7.11/src/linktools/version.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
@author  : Hu Ji
@file    : version.py
@time    : 2018/11/25
@site    :
@software: PyCharm

              ,----------------,              ,---------,
         ,-----------------------,          ,"        ,"|
       ,"                      ,"|        ,"        ,"  |
      +-----------------------+  |      ,"        ,"    |
      |  .-----------------.  |  |     +---------+      |
      |  |                 |  |  |     | -==----'|      |
      |  | $ sudo rm -rf / |  |  |     |         |      |
      |  |                 |  |  |/----|`---=    |      |
      |  |                 |  |  |   ,/|==== ooo |      ;
      |  |                 |  |  |  // |(((( [33]|    ,"
      |  `-----------------'  |," .;'| |((((     |  ,"
      +-----------------------+  ;;  | |         |,"
         /_)______________(_/  //'   | +---------+
    ___________________________/___  `,
   /  oooooooooooooooo  .o.  oooo /,   \,"-----------
  / ==ooooooooooooooo==.o.  ooo= //   ,`\--{)B     ,"
 /_==__==========__==_ooo__ooo=_/'   /___________,"
"""

__version__ = "0.7.11"
if not __version__[:1].isdigit():
    __version__ = "0.0.1-debug"

__name__ = "linktools"
__author__ = "Hu Ji"
__email__ = "669898595@qq.com"
__url__ = "https://github.com/ice-black-tea/Zelda/tree/master"
__summary__ = f"{__name__} toolkit"
__description__ = f"""\
    ___       __   __              __    
   / (_)___  / /__/ /_____  ____  / /____
  / / / __ \\/ //_/ __/ __ \\/ __ \\/ / ___/  {__summary__}
 / / / / / / ,< / /_/ /_/ / /_/ / (__  )     by: @{__author__} 
/_/_/_/ /_/_/|_|\\__/\\____/\\____/_/____/  
"""

==> linktools-0.7.20.tar.gz: linktools-0.7.20/src/linktools/version.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
@author  : Hu Ji
@file    : version.py
@time    : 2018/11/25
@site    :
@software: PyCharm

              ,----------------,              ,---------,
         ,-----------------------,          ,"        ,"|
       ,"                      ,"|        ,"        ,"  |
      +-----------------------+  |      ,"        ,"    |
      |  .-----------------.  |  |     +---------+      |
      |  |                 |  |  |     | -==----'|      |
      |  | $ sudo rm -rf / |  |  |     |         |      |
      |  |                 |  |  |/----|`---=    |      |
      |  |                 |  |  |   ,/|==== ooo |      ;
      |  |                 |  |  |  // |(((( [33]|    ,"
      |  `-----------------'  |," .;'| |((((     |  ,"
      +-----------------------+  ;;  | |         |,"
         /_)______________(_/  //'   | +---------+
    ___________________________/___  `,
   /  oooooooooooooooo  .o.  oooo /,   \,"-----------
  / ==ooooooooooooooo==.o.  ooo= //   ,`\--{)B     ,"
 /_==__==========__==_ooo__ooo=_/'   /___________,"
"""

__release__ = True
__version__ = "0.7.20"
__name__ = "linktools"
__author__ = "Hu Ji"
__email__ = "669898595@qq.com"
__url__ = "https://github.com/ice-black-tea/Zelda"
__summary__ = f"{__name__} toolkit"
__description__ = f"""\
    ___       __   __              __    
   / (_)___  / /__/ /_____  ____  / /____
  / / / __ \\/ //_/ __/ __ \\/ __ \\/ / ___/  {__summary__}
 / / / / / / ,< / /_/ /_/ / /_/ / (__  )     by: @{__author__} 
/_/_/_/ /_/_/|_|\\__/\\____/\\____/_/____/  
"""
